ImportedWalletBackup class

Constructors

ImportedWalletBackup({required String mnemonicPhrase, required String address, required String rootId, required String privateKeyBase58, required SolanaDerivation derivation})
const

Properties

address String
final
derivation SolanaDerivation
final
hashCode int
The hash code for this object.
no setterinherited
mnemonicPhrase String
final
privateKeyBase58 String
final
rootId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited