WalletMaterial class

Constructors

WalletMaterial({required WalletInfo info, required WalletSecret secret, MnemonicSecret? mnemonicSecret})
const

Properties

address String
no setter
derivationPath String?
no setter
hashCode int
The hash code for this object.
no setterinherited
info WalletInfo
final
mnemonic List<String>?
no setter
mnemonicPhrase String?
no setter
mnemonicSecret MnemonicSecret?
final
privateKeyBase58 String
no setter
rootId String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secret WalletSecret
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited