WalletUiText class

Constructors

WalletUiText({String setupTitle = 'Set up your wallet', String setupMessage = 'Create a new wallet or restore one using an existing recovery phrase.', String createAction = 'Create new wallet', String restoreAction = 'Restore from mnemonic', String createTitle = 'Create wallet', String restoreTitle = 'Restore wallet', String securityMessage = 'You can copy or download your recovery phrase, but we recommend ' 'writing it down on paper and storing it somewhere safe.', String walletAddressLabel = 'Wallet address', String privateKeyLabel = 'Private key', String recoveryPhraseLengthLabel = 'Recovery phrase length', String continueAction = 'Continue', String restoreContinueAction = 'Restore and continue', String copyAddressTooltip = 'Copy wallet address', String copyPrivateKeyTooltip = 'Copy private key', String copyPhraseTooltip = 'Copy recovery phrase', String downloadPhraseTooltip = 'Download recovery phrase', String generatePhraseTooltip = 'Generate a new phrase', String pastePhraseTooltip = 'Paste recovery phrase', String importPhraseTooltip = 'Import recovery phrase file', String importWalletTooltip = 'Import this wallet with recovery phrase', String importAddressTooltip = 'Import this address with private key', String addressCopiedMessage = 'Wallet address copied', String privateKeyCopiedMessage = 'Private key copied for 1 minute', String phraseCopiedMessage = 'Recovery phrase copied for 1 minute', String backupSavedMessage = 'Recovery phrase backup saved', String hostCompletionError = 'The wallet was securely saved, but the host app could not finish ' 'setup. You can safely try continuing again.'})
const

Properties

addressCopiedMessage String
final
backupSavedMessage String
final
continueAction String
final
copyAddressTooltip String
final
copyPhraseTooltip String
final
copyPrivateKeyTooltip String
final
createAction String
final
createTitle String
final
downloadPhraseTooltip String
final
generatePhraseTooltip String
final
hashCode int
The hash code for this object.
no setterinherited
hostCompletionError String
final
importAddressTooltip String
final
importPhraseTooltip String
final
importWalletTooltip String
final
pastePhraseTooltip String
final
phraseCopiedMessage String
final
privateKeyCopiedMessage String
final
privateKeyLabel String
final
recoveryPhraseLengthLabel String
final
restoreAction String
final
restoreContinueAction String
final
restoreTitle String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
securityMessage String
final
setupMessage String
final
setupTitle String
final
walletAddressLabel String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited