WalletUiText({StringsetupTitle = 'Set up your wallet', StringsetupMessage = 'Create a new wallet or restore one using an existing recovery phrase.', StringcreateAction = 'Create new wallet', StringrestoreAction = 'Restore from mnemonic', StringcreateTitle = 'Create wallet', StringrestoreTitle = 'Restore wallet', StringsecurityMessage = 'You can copy or download your recovery phrase, but we recommend ' 'writing it down on paper and storing it somewhere safe.', StringwalletAddressLabel = 'Wallet address', StringprivateKeyLabel = 'Private key', StringrecoveryPhraseLengthLabel = 'Recovery phrase length', StringcontinueAction = 'Continue', StringrestoreContinueAction = 'Restore and continue', StringcopyAddressTooltip = 'Copy wallet address', StringcopyPrivateKeyTooltip = 'Copy private key', StringcopyPhraseTooltip = 'Copy recovery phrase', StringdownloadPhraseTooltip = 'Download recovery phrase', StringgeneratePhraseTooltip = 'Generate a new phrase', StringpastePhraseTooltip = 'Paste recovery phrase', StringimportPhraseTooltip = 'Import recovery phrase file', StringimportWalletTooltip = 'Import this wallet with recovery phrase', StringimportAddressTooltip = 'Import this address with private key', StringaddressCopiedMessage = 'Wallet address copied', StringprivateKeyCopiedMessage = 'Private key copied for 1 minute', StringphraseCopiedMessage = 'Recovery phrase copied for 1 minute', StringbackupSavedMessage = 'Recovery phrase backup saved', StringhostCompletionError = 'The wallet was securely saved, but the host app could not finish ' 'setup. You can safely try continuing again.'})