WalletStore class abstract
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addWalletAddress(
{required String rootId, required String address}) → Future< void> -
deleteMnemonicSecret(
{required String rootId}) → Future< void> -
deleteWallet(
{required String address}) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readMnemonicSecret(
{required String rootId}) → Future< MnemonicSecret?> -
readWalletInfo(
{required String address}) → Future< WalletInfo?> -
readWalletInfos(
{required String rootId}) → Future< List< WalletInfo> > -
readWalletSecret(
{required String address}) → Future< WalletSecret?> -
saveMnemonicSecret(
MnemonicSecret secret) → Future< void> -
saveWalletAddresses(
{required String rootId, required List< String> addresses}) → Future<void> -
saveWalletInfo(
WalletInfo info) → Future< void> -
saveWalletMaterial(
WalletMaterial material) → Future< void> -
saveWalletSecret(
WalletSecret secret) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited